==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/no-NO/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Bekreft sletting av flere enheter',
    'bulk_restore'      => 'Bekreft sletting av flere enheter', 
  'bulk_delete_help'	=> 'Se gjennom listen over enheter som er valgt for sletting. Etter sletting er det mulig å gjenopprette enheter, men nåværende koblinger til brukere vil ikke lenger finnes.',
  'bulk_restore_help'	=> 'Se gjennom ressursene for massegjennoppretning nedenfor. Når de er gjenopprettet vil ikke disse eiendelene være knyttet til brukere de ble gitt til tidligere.',
  'bulk_delete_warn'	=> 'Du er i ferd med å slette :asset_count enheter.',
  'bulk_restore_warn'	=> 'Du er i ferd med å gjennopprette :asset_count enheter.',
    'bulk_update'		=> 'Masseoppdater eiendeler',
    'bulk_update_help'	=> 'Dette skjemaet lar deg oppdatere flere eiendeler på en gang. Fyll kun ut feltene du ønsker å endre. Tomme felter forblir uendret. ',
    'bulk_update_warn'	=> 'Du er i ferd med å endre egenskapene til en ressurs. Du er i ferd med å endre egenskapene til :asset_count enheter.',
    'bulk_update_with_custom_field' => 'Merk at ressursene er av :asset_model_count ulike modeller.',
    'bulk_update_model_prefix' => 'På modeller', 
    'bulk_update_custom_field_unique' => 'Dette er et unikt felt og kan ikke masseredigeres.',
    'checkedout_to'		=> 'Utsjekket til',
    'checkout_date'		=> 'Utsjekkdato',
    'checkin_date'		=> 'Innsjekkdato',
    'checkout_to'		=> 'Sjekk ut til',
    'cost'				=> 'Innkjøpskostnad',
    'create'			=> 'Opprett eiendel',
    'date'				=> 'Innkjøpsdato',
    'depreciation'	    => 'avskrivninger',
    'depreciates_on'	=> 'Avskrivningstype',
    'default_location'	=> 'Standard plassering',
    'default_location_phone' => 'Standard plasseringstelefon',
    'eol_date'			=> 'EOL dato',
    'eol_rate'			=> 'EOL-rate',
    'expected_checkin'  => 'Forventet dato for innsjekk',
    'expires'			=> 'Utløper',
    'fully_depreciated'	=> 'Ferdig nedskrevet',
    'help_checkout'		=> 'Hvis du ønsker å tildele denne eiendelen umiddelbart, velger du "klar til å distribuere" fra status listen ovenfor. ',
    'mac_address'		=> 'MAC-adresse',
    'manufacturer'		=> 'Produsent',
    'model'				=> 'Modell',
    'months'			=> 'måneder',
    'name'				=> 'Navn',
    'notes'				=> 'Notater',
    'order'				=> 'Ordrenummer',
    'qr'				=> 'QR-kode',
    'requestable'		=> 'Brukere kan be om eiendel',
    'select_statustype'	=> 'Velg statustype',
    'serial'			=> 'Serienummer',
    'status'			=> 'Status',
    'tag'				=> 'Eiendelsmerke',
    'update'			=> 'Oppdater eiendel',
    'warranty'			=> 'Garanti',
        'warranty_expires'		=> 'Garantien utløper',
    'years'				=> 'år',
    'asset_location' => 'Oppdater lokasjon for eiendelen',
    'asset_location_update_default_current' => 'Oppdater standardlokasjon OG faktisk lokasjon',
    'asset_location_update_default' => 'Oppdater bare standardlokasjon',
    'asset_location_update_actual' => 'Oppdater bare faktisk plassering',
    'asset_not_deployable' => 'Den eiendelstatusen gjør at denne eiendelen ikke kan sjekkes ut.',
    'asset_deployable' => 'Den statusen gjør det mulig å sjekke ut denne eiendelen.',
    'processing_spinner' => 'Behandler... (Dette kan ta litt tid for store filer)',
    'optional_infos'  => 'Valgfri informasjon',
    'order_details'   => 'Ordrerelatert informasjon'
];

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/no-NO/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Bekreft sletting av flere enheter',
    'bulk_restore'      => 'Bekreft sletting av flere enheter', 
  'bulk_delete_help'	=> 'Se gjennom listen over enheter som er valgt for sletting. Etter sletting er det mulig å gjenopprette enheter, men nåværende koblinger til brukere vil ikke lenger finnes.',
  'bulk_restore_help'	=> 'Se gjennom ressursene for massegjennoppretning nedenfor. Når de er gjenopprettet vil ikke disse eiendelene være knyttet til brukere de ble gitt til tidligere.',
  'bulk_delete_warn'	=> 'Du er i ferd med å slette :asset_count enheter.',
  'bulk_restore_warn'	=> 'Du er i ferd med å gjennopprette :asset_count enheter.',
    'bulk_update'		=> 'Masseoppdater eiendeler',
    'bulk_update_help'	=> 'Dette skjemaet lar deg oppdatere flere eiendeler på en gang. Fyll kun ut feltene du ønsker å endre. Tomme felter forblir uendret. ',
    'bulk_update_warn'	=> 'Du er i ferd med å endre egenskapene til en ressurs. Du er i ferd med å endre egenskapene til :asset_count enheter.',
    'bulk_update_with_custom_field' => 'Merk at ressursene er av :asset_model_count ulike modeller.',
    'bulk_update_model_prefix' => 'På modeller', 
    'bulk_update_custom_field_unique' => 'Dette er et unikt felt og kan ikke masseredigeres.',
    'checkedout_to'		=> 'Utsjekket til',
    'checkout_date'		=> 'Utsjekkdato',
    'checkin_date'		=> 'Innsjekkdato',
    'checkout_to'		=> 'Sjekk ut til',
    'cost'				=> 'Innkjøpskostnad',
    'create'			=> 'Opprett eiendel',
    'date'				=> 'Innkjøpsdato',
    'depreciation'	    => 'avskrivninger',
    'depreciates_on'	=> 'Avskrivningstype',
    'default_location'	=> 'Standard plassering',
    'default_location_phone' => 'Standard plasseringstelefon',
    'eol_date'			=> 'EOL dato',
    'eol_rate'			=> 'EOL-rate',
    'expected_checkin'  => 'Forventet dato for innsjekk',
    'expires'			=> 'Utløper',
    'fully_depreciated'	=> 'Ferdig nedskrevet',
    'help_checkout'		=> 'Hvis du ønsker å tildele denne eiendelen umiddelbart, velger du "klar til å distribuere" fra status listen ovenfor. ',
    'mac_address'		=> 'MAC-adresse',
    'manufacturer'		=> 'Produsent',
    'model'				=> 'Modell',
    'months'			=> 'måneder',
    'name'				=> 'Navn',
    'notes'				=> 'Notater',
    'order'				=> 'Ordrenummer',
    'qr'				=> 'QR-kode',
    'requestable'		=> 'Brukere kan be om eiendel',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Velg statustype',
    'serial'			=> 'Serienummer',
    'status'			=> 'Status',
    'tag'				=> 'Eiendelsmerke',
    'update'			=> 'Oppdater eiendel',
    'warranty'			=> 'Garanti',
        'warranty_expires'		=> 'Garantien utløper',
    'years'				=> 'år',
    'asset_location' => 'Oppdater lokasjon for eiendelen',
    'asset_location_update_default_current' => 'Oppdater standardlokasjon OG faktisk lokasjon',
    'asset_location_update_default' => 'Oppdater bare standardlokasjon',
    'asset_location_update_actual' => 'Oppdater bare faktisk plassering',
    'asset_not_deployable' => 'Den eiendelstatusen gjør at denne eiendelen ikke kan sjekkes ut.',
    'asset_not_deployable_checkin' => 'That asset status is not deployable. Using this status label will checkin the asset.',
    'asset_deployable' => 'Den statusen gjør det mulig å sjekke ut denne eiendelen.',
    'processing_spinner' => 'Behandler... (Dette kan ta litt tid for store filer)',
    'optional_infos'  => 'Valgfri informasjon',
    'order_details'   => 'Ordrerelatert informasjon'
];
